@@ -1,11 +1,12 @@
 '''
-Manage BSD init services (``/etc/rc.d``).
+Manage BSD init services (``/etc/rc.d``, ``/usr/local/etc/rc.d``).
 '''
 
 from __future__ import unicode_literals
 
 from pyinfra.api import operation
 from pyinfra.facts.bsdinit import RcdStatus
+from pyinfra.facts.server import Os
 
 from . import files
 from .util.service import handle_service_control
@@ -19,7 +20,7 @@ def service(
     state=None, host=None,
 ):
     '''
-    Manage the state of BSD init (/etc/rc.d) services.
+    Manage the state of BSD init services.
 
     + service: name of the service to manage
     + running: whether the service should be running
@@ -29,12 +30,16 @@ def service(
     + enabled: whether this service should be enabled/disabled on boot
     '''
 
+    status_argument = 'status'
+    if host.get_fact(Os) == 'OpenBSD':
+        status_argument = 'check'
+
     yield handle_service_control(
         host,
         service, RcdStatus,
-        '/etc/rc.d/{0} {1}',
+        'test -e /etc/rc.d/{0} && /etc/rc.d/{0} {1} || /usr/local/etc/rc.d/{0} {1}',
         running, restarted, reloaded, command,
-        status_argument='check',
+        status_argument=status_argument,
     )
 
     # BSD init is simple, just add/remove <service>_enabled="YES"
